@@ -523,8 +523,8 @@ class rcube_install
         '0.4-beta', '0.4.2',
         '0.5-beta', '0.5', '0.5.1',
         '0.6-beta', '0.6',
-        '0.7-beta', '0.7', '0.7.1', '0.7.2',
-        '0.8-beta', '0.8-rc', '0.8.0',
+        '0.7-beta', '0.7', '0.7.1', '0.7.2', '0.7.3',
+        '0.8-beta', '0.8-rc', '0.8.0', '0.8.1',
     ));
     return $select;
   }
